MsgSignature class

Signatures used to sign Ethereum transactions and messages.

Constructors

MsgSignature(BigInt r, BigInt s, int v)

Properties

hashCode → int
The hash code for this object.
no setterinherited
r → BigInt
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s → BigInt
final
v → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited